PyBaccarat: pybaccarat.baccaratsystems.Dragon Class Reference

PyBaccarat visit the ministry of silly walks

Public Member Functions | Public Attributes | List of all members
pybaccarat.baccaratsystems.Dragon Class Reference

TBD. More...

Inheritance diagram for pybaccarat.baccaratsystems.Dragon:

## Public Member Functions
def | __init__ (self)
| TBD.
def | update_count (self, rank)
| Add these ranks to the count. More...
def | new_shoe (self, burn_card)
| Begin a new shoe. More...
def | hand_pre (self, hand_num)
def | hand_post (self, win_diff, player, banker)
| TBD.
def | end_shoe (self)
| TBD.
def | __init__ (self)
| TBD.
def | update_count (self, rank)
| Add these ranks to the count. More...
def | new_shoe (self, burn_card)
| Begin a new shoe. More...
def | hand_pre (self, hand_num)
def | hand_post (self, win_diff, player, banker)
| TBD.
def | end_shoe (self)
| TBD.

## Public Attributes
| dragon_play
| !< dragon_play is used for display out
| dragon_count
| !< dragon_count used to count my system
| dragon_dict
| !< dragon_dict tracks the side bet difference results
| hand_number

## Detailed Description

TBD.

## Member Function Documentation

## ◆ new_shoe() [1/2]

def pybaccarat.baccaratsystems.Dragon.new_shoe | ( |  | self,
|  |  | burn_card
| ) |  |

Begin a new shoe.

Parameters

  burn_card | Card

## ◆ new_shoe() [2/2]

def pybaccarat.baccaratsystems.Dragon.new_shoe | ( |  | self,
|  |  | burn_card
| ) |  |

Begin a new shoe.

Parameters

  burn_card | Card

## ◆ update_count() [1/2]

def pybaccarat.baccaratsystems.Dragon.update_count | ( |  | self,
|  |  | rank
| ) |  |

Add these ranks to the count.

Parameters

  rank | int card rank's to add to system count

## ◆ update_count() [2/2]

def pybaccarat.baccaratsystems.Dragon.update_count | ( |  | self,
|  |  | rank
| ) |  |

Add these ranks to the count.

Parameters

  rank | int card rank's to add to system count

The documentation for this class was generated from the following file:

- build/lib/pybaccarat/baccaratsystems.py